==> elasticsearch-6.3.2-sources.jar: org/elasticsearch/action/admin/indices/alias/IndicesAliasesResponse.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.indices.alias;

import org.elasticsearch.action.support.master.AcknowledgedResponse;
import org.elasticsearch.common.io.stream.StreamInput;
import org.elasticsearch.common.io.stream.StreamOutput;
import org.elasticsearch.common.xcontent.ConstructingObjectParser;
import org.elasticsearch.common.xcontent.XContentParser;

import java.io.IOException;

/**
 * A response for a add/remove alias action.
 */
public class IndicesAliasesResponse extends AcknowledgedResponse {

    private static final ConstructingObjectParser<IndicesAliasesResponse, Void> PARSER = new ConstructingObjectParser<>("indices_aliases",
            true, args -> new IndicesAliasesResponse((boolean) args[0]));
    static {
        declareAcknowledgedField(PARSER);
    }

    IndicesAliasesResponse() {
    }

    IndicesAliasesResponse(boolean acknowledged) {
        super(acknowledged);
    }

    @Override
    public void readFrom(StreamInput in) throws IOException {
        super.readFrom(in);
        readAcknowledged(in);
    }

    @Override
    public void writeTo(StreamOutput out) throws IOException {
        super.writeTo(out);
        writeAcknowledged(out);
    }

    public static IndicesAliasesResponse fromXContent(XContentParser parser) {
        return PARSER.apply(parser, null);
    }
}

==> elasticsearch-6.4.0-sources.jar: org/elasticsearch/action/admin/indices/alias/IndicesAliasesResponse.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.indices.alias;

import org.elasticsearch.action.support.master.AcknowledgedResponse;
import org.elasticsearch.common.xcontent.ConstructingObjectParser;
import org.elasticsearch.common.xcontent.XContentParser;

/**
 * A response for a add/remove alias action.
 */
public class IndicesAliasesResponse extends AcknowledgedResponse {

    private static final ConstructingObjectParser<IndicesAliasesResponse, Void> PARSER = new ConstructingObjectParser<>("indices_aliases",
            true, args -> new IndicesAliasesResponse((boolean) args[0]));
    static {
        declareAcknowledgedField(PARSER);
    }

    IndicesAliasesResponse() {
    }

    IndicesAliasesResponse(boolean acknowledged) {
        super(acknowledged);
    }

    public static IndicesAliasesResponse fromXContent(XContentParser parser) {
        return new IndicesAliasesResponse(parseAcknowledged(parser));
    }
}
